// Ionic Starter App

// angular.module is a global place for creating, registering and retrieving Angular modules
// 'starter' is the name of this angular module example (also set in a <body> attribute in index.html)
// the 2nd parameter is an array of 'requires'
// 'starter.services' is found in services.js
// 'starter.controllers' is found in controllers.js
angular.module('starter', ['ionic', 'starter.controllers', 'starter.services','ngCordova','ion-gallery'])
.config(function ($httpProvider) {
  // 头部配置
  $httpProvider.defaults.headers.post['Content-Type'] = 'application/x-www-form-urlencoded;charset=utf-8';
  $httpProvider.defaults.headers.post['Accept'] = 'application/json, text/javascript, */*; q=0.01';
  $httpProvider.defaults.headers.post['X-Requested-With'] = 'XMLHttpRequest';

  /**
   * 重写angular的param方法，使angular使用jquery一样的数据序列化方式  The workhorse; converts an object to x-www-form-urlencoded serialization.
   * @param {Object} obj
   * @return {String}
   */
  var param = function (obj) {
    var query = '', name, value, fullSubName, subName, subValue, innerObj, i;

    for (name in obj) {
      value = obj[name];

      if (value instanceof Array) {
        for (i = 0; i < value.length; ++i) {
          subValue = value[i];
          fullSubName = name + '[' + i + ']';
          innerObj = {};
          innerObj[fullSubName] = subValue;
          query += param(innerObj) + '&';
        }
      }
      else if (value instanceof Object) {
//            	for (subName in value) {
//                    subValue = value[subName];
//                    fullSubName = name + '[' + subName + ']';
//                    innerObj = {};
//                    innerObj[fullSubName] = subValue;
//                    query += param(innerObj) + '&';
//                }
        for (subName in value) {
          subValue = value[subName];
          if(subValue !== undefined && subValue !== null){
            fullSubName = name + '.' + subName;
            innerObj = {};
            innerObj[fullSubName] = subValue;
            query += param(innerObj) + '&';
          }
        }
      }
      else if (value !== undefined && value !== null)
        query += encodeURIComponent(name) + '=' + encodeURIComponent(value) + '&';
    }

    return query.length ? query.substr(0, query.length - 1) : query;
  };

  // Override $http service's default transformRequest
  $httpProvider.defaults.transformRequest = [function (data) {
    return angular.isObject(data) && String(data) !== '[object File]' ? param(data) : data;
  }];

})
.run(function($ionicPlatform) {
  $ionicPlatform.ready(function() {
    // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
    // for form inputs)
    if (window.cordova && window.cordova.plugins && window.cordova.plugins.Keyboard) {
      cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
      cordova.plugins.Keyboard.disableScroll(true);

    }
    if (window.StatusBar) {
      // org.apache.cordova.statusbar required
      StatusBar.styleDefault();
    }
  });
})

.config(function($stateProvider, $urlRouterProvider,$ionicConfigProvider) {
  $ionicConfigProvider.platform.ios.tabs.style('standard');
  $ionicConfigProvider.platform.ios.tabs.position('bottom');
  $ionicConfigProvider.platform.android.tabs.style('standard');
  $ionicConfigProvider.platform.android.tabs.position('bottom');
  $ionicConfigProvider.platform.ios.navBar.alignTitle('center');
  $ionicConfigProvider.platform.android.navBar.alignTitle('center');
  $ionicConfigProvider.platform.ios.backButton.previousTitleText('').icon('ion-ios-arrow-thin-left');
  $ionicConfigProvider.platform.android.backButton.previousTitleText('').icon('ion-android-arrow-back');
  $ionicConfigProvider.platform.ios.views.transition('ios');
  $ionicConfigProvider.platform.android.views.transition('android');
/*  $ionicConfigProvider.views.transition('none');*/
  // Ionic uses AngularUI Router which uses the concept of states
  // Learn more here: https://github.com/angular-ui/ui-router
  // Set up the various states which the app can be in.
  // Each state's controller can be found in controllers.js
  $stateProvider
  // setup an abstract state for the tabs directive
    .state('tab', {
    url: '/tab',
    abstract: true,
    templateUrl: 'templates/tabs.html',
    controller: 'IndexCtrl'
  })

  // Each tab has its own nav history stack:

  .state('tab.zones', {
    url: '/zones',
    views: {
      'tab-zones': {
        templateUrl: 'templates/tab-zones.html',
        controller: 'ZonesCtrl'
      }
    }
  })
    .state('tab.zonesAdd', {
      url: '/zonesAdd',
      views: {
        'tab-zones': {
          templateUrl: 'templates/addZone.html',
          controller: 'ZonesAddCtrl'
        }
      }
    })
    .state('tab.map', {
      url: '/maps',
      cache:false,
      views: {
        'tab-zones': {
          templateUrl: 'templates/maps.html',
          controller: 'MapCtrl'
        }
      }
    })
    .state('tab.mapRelic', {
      url: '/mapRelics',
      views: {
        'tab-zones': {
          templateUrl: 'templates/mapRelics.html',
          controller: 'MapRelicsCtrl'
        }
      }
    })
    .state('tab.city', {
      url: '/citys/:relicId',
      views: {
        'tab-zones': {
          templateUrl: 'templates/relicRemark.html',
          controller: 'RelicRemarkCtrl'
        }
      }
    })
    .state('tab.comments', {
      url: '/comments/:relicId',
      views: {
        'tab-zones': {
          templateUrl: 'templates/relicComments.html',
          controller: 'RelicCommentsCtrl'
        }
      }
    })
    .state('tab.commentsT', {
      url: '/commentsT/:relicId',
      views: {
        'tab-account': {
          templateUrl: 'templates/relicComments.html',
          controller: 'RelicCommentsCtrl'
        }
      }
    })
    .state('tab.commentsS', {
      url: '/commentsS/:relicId',
      views: {
        'tab-chats': {
          templateUrl: 'templates/relicComments.html',
          controller: 'RelicCommentsCtrl'
        }
      }
    })
    .state('tab.storyComments', {
      url: '/storyComments/:storyId',
      views: {
        'tab-zones': {
          templateUrl: 'templates/relicComments.html',
          controller: 'StoryCommentsCtrl'
        }
      }
    })
    .state('tab.storyCommentsS', {
      url: '/storyCommentsS/:storyId',
      views: {
        'tab-chats': {
          templateUrl: 'templates/relicComments.html',
          controller: 'StoryCommentsCtrl'
        }
      }
    })
    .state('tab.storyCommentsT', {
      url: '/storyCommentsT/:storyId',
      views: {
        'tab-account': {
          templateUrl: 'templates/relicComments.html',
          controller: 'StoryCommentsCtrl'
        }
      }
    })
    .state('tab.relicRemarkS', {
      url: '/reliRemarkS/:relicId',
      views: {
        'tab-chats': {
          templateUrl: 'templates/relic/relicRemarkS.html',
          controller: 'RelicRemarkCtrl'
        }
      }
    })
    .state('tab.relicRemarkT', {
      url: '/reliRemarkT/:relicId',
      views: {
        'tab-account': {
          templateUrl: 'templates/relic/relicRemarkT.html',
          controller: 'RelicRemarkCtrl'
        }
      }
    })
    .state('tab.zone', {
      url: '/zones/:zoneId',
      views: {
        'tab-zones': {
          templateUrl: 'templates/tab-relics.html',
          controller: 'RelicsCtrl'
        }
      }
    })
    .state('tab.addRelic', {
      url: '/zones/:zoneId',
      views: {
        'tab-zones': {
          templateUrl: 'templates/addRelic.html',
          controller: 'RelicsAddCtrl'
        }
      }
    })
    .state('tab.relic', {
    url: '/relics/:relicId',
    views: {
      'tab-zones': {
        templateUrl: 'templates/tab-relicDetail.html',
        controller: 'RelicDetailCtrl'
      }
    }
  })
    .state('tab.relicS', {
      url: '/relicsS/:relicId',
      views: {
        'tab-chats': {
          templateUrl: 'templates/relic/tab-relicDetailS.html',
          controller: 'RelicDetailCtrl'
        }
      }
    })
    .state('tab.relicT', {
      url: '/relicsT/:relicId',
      views: {
        'tab-account': {
          templateUrl: 'templates/relic/tab-relicDetailT.html',
          controller: 'RelicDetailCtrl'
        }
      }
    })
    .state('tab.relicRemark', {
      url: '/relicRemark/:relicId',
      views: {
        'tab-zones': {
          templateUrl: 'templates/tab-relicRemark.html',
          controller: 'RelicRemarkCtrl'
        }
      }
    })
    .state('tab.relicCollect', {
      url: '/relicsCollect/:relicId',
      views: {
        'tab-account': {
          templateUrl: 'templates/relic/tab-relicDetailT.html',
          controller: 'RelicDetailCtrl'
        }
      }
    })
    .state('tab.zoneRemark', {
      url: '/zoneRemark',
      views: {
        'tab-zones': {
          templateUrl: 'templates/tab-zoneRemark.html',
          controller: 'ZoneRemarkCtrl'
        }
      }
    })
    .state('tab.story', {
      url: '/storyDetail/:storyId',
      views: {
        'tab-zones': {
          templateUrl: 'templates/tab-storyDetail.html',
          controller: 'StoryDetailCtrl'
        }
      }
    })
    .state('tab.storyS', {
      url: '/storyDetailS/:storyId',
      views: {
        'tab-chats': {
          templateUrl: 'templates/story/tab-storyDetailS.html',
          controller: 'StoryDetailCtrl'
        }
      }
    })
    .state('tab.storyT', {
      url: '/storyDetailT/:storyId',
      views: {
        'tab-account': {
          templateUrl: 'templates/story/tab-storyDetailT.html',
          controller: 'StoryDetailCtrl'
        }
      }
    })
    .state('tab.picList', {
      url: '/picList/:relicId',
      views: {
        'tab-zones': {
          templateUrl: 'templates/tab-picList.html',
          controller: 'PicCtrl'
        }
      }
    })
    .state('tab.picListS', {
      url: '/picListS/:relicId',
      views: {
        'tab-chats': {
          templateUrl: 'templates/tab-picList.html',
          controller: 'PicCtrl'
        }
      }
    })
    .state('tab.picListT', {
      url: '/picListT/:relicId',
      views: {
        'tab-account': {
          templateUrl: 'templates/tab-picList.html',
          controller: 'PicCtrl'
        }
      }
    })
  .state('tab.storys', {
      url: '/storys',
      views: {
        'tab-chats': {
          templateUrl: 'templates/tab-storys.html',
          controller: 'StorysCtrl'
        }
      }
    })
    .state('tab.chats', {
      url: '/chats',
      views: {
        'tab-chats': {
          templateUrl: 'templates/tab-chats.html',
          controller: 'ChatsCtrl'
        }
      }
    })
    .state('tab.chat-detail', {
      url: '/chats/:chatId',
      views: {
        'tab-chats': {
          templateUrl: 'templates/chat-detail.html',
          controller: 'ChatDetailCtrl'
        }
      }
    })

  .state('tab.account', {
    url: '/account',
    views: {
      'tab-account': {
        templateUrl: 'templates/tab-account.html',
        controller: 'AccountCtrl'
      }
    }
  })
  .state('tab.collects', {
    url: '/collects',
    views: {
      'tab-account': {
        templateUrl: 'templates/tab-collects.html',
        controller: 'CollectsCtrl'
      }
    }
  });
  // if none of the above states are matched, use this as the fallback
  $urlRouterProvider.otherwise('/tab/zones');

});
